@@ -10,7 +10,7 @@ Features
 Here are some of the features of Plonk:
 
 - Read in Phantom HDF snapshot files.
-- Read in global quantity and sink evolution files.
+- Read in global quantity and sink time series data files.
 - Encapsulate entire simulation data as Simulation object.
 - Access particle and sink arrays.
 - Access simulation parameters and units.
@@ -56,12 +56,13 @@ available at https://github.com/dmentipl/plonk.
 
 import importlib_metadata as _importlib_metadata
 
+from ._config import read_config, write_config
 from ._logging import logger_init as _logger_init
-from ._units import add_units, array_units, units
+from ._units import Quantity, add_units, array_units, units
 from .analysis.profile import Profile, load_profile
-from .simulation.evolution import load_ev
-from .simulation.simulation import Simulation, load_sim
-from .snap.readers import load_snap
+from .simulation.simulation import Simulation, load_sim, load_simulation
+from .simulation.time_series import load_ev, load_time_series
+from .snap import load_snap
 from .snap.snap import Sinks, Snap, SnapLike, SubSnap
 from .visualize.animation import animate
 from .visualize.interpolation import interpolate
@@ -76,6 +77,7 @@ add_units()
 
 __all__ = [
     'Profile',
+    'Quantity',
     'Simulation',
     'Sinks',
     'Snap',
@@ -89,9 +91,13 @@ __all__ = [
     'load_ev',
     'load_profile',
     'load_sim',
+    'load_simulation',
     'load_snap',
+    'load_time_series',
     'plot',
+    'read_config',
     'units',
     'vector',
     'visualize_sim',
+    'write_config',
 ]
