@@ -13,8 +13,10 @@ file_handler = logging.FileHandler('.plonk.log')
 console_handler.setLevel(logging.INFO)
 file_handler.setLevel(logging.DEBUG)
 
-console_format = logging.Formatter('%(levelname)s - %(message)s')
-file_format = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
+console_format = logging.Formatter('%(levelname)s - %(funcName)s - %(message)s')
+file_format = logging.Formatter(
+    '%(asctime)s - %(levelname)s - %(funcName)s - %(message)s'
+)
 console_handler.setFormatter(console_format)
 file_handler.setFormatter(file_format)
 
