@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Union
 
 import numpy as np
 
@@ -12,9 +12,9 @@ from .._units import units as plonk_units
 from ..utils.math import cross, norm
 
 if TYPE_CHECKING:
-    from ..snap.snap import SnapLike
+    from ..snap.snap import Sinks, SnapLike
 
-ORIGIN = (0, 0, 0) * plonk_units.au
+ORIGIN = (0, 0, 0) * plonk_units('meter')
 MOLECULAR_HYDROGEN_WEIGHT = 2.381
 
 # Derived quantities require some arrays already present
@@ -25,21 +25,16 @@ array_requires = {
     'azimuthal_angle': ['position'],
     'dust_density': ['density', 'dust_fraction'],
     'dust_mass': ['dust_fraction', 'mass'],
-    'eccentricity': ['position', 'velocity'],
     'gas_density': ['density', 'dust_fraction'],
     'gas_fraction': ['dust_fraction'],
     'gas_mass': ['dust_fraction', 'mass'],
-    'inclination': ['mass', 'position', 'velocity'],
-    'keplerian_frequency': ['position'],
     'kinetic_energy': ['mass', 'velocity'],
     'momentum': ['mass', 'velocity'],
     'polar_angle': ['position'],
     'radius_cylindrical': ['position'],
     'radius_spherical': ['position'],
-    'semi_major_axis': ['position', 'velocity'],
     'specific_angular_momentum': ['position', 'velocity'],
     'specific_kinetic_energy': ['velocity'],
-    'stokes_number': ['position', 'stopping_time'],
     'temperature': ['sound_speed'],
     'velocity_radial_cylindrical': ['position', 'velocity'],
     'velocity_radial_spherical': ['position', 'velocity'],
@@ -53,7 +48,7 @@ dust_arrays = ['dust_density', 'dust_mass', 'stokes_number']
 
 
 def angular_momentum(
-    snap: SnapLike, origin: Quantity = None, ignore_accreted: bool = False
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
 ) -> Quantity:
     """Calculate the angular momentum.
 
@@ -82,19 +77,27 @@ def angular_momentum(
         pos = snap['position']
         vel = snap['velocity']
 
-    origin = snap.translation if snap.translation is not None else ORIGIN
+    if origin is None:
+        origin = ORIGIN
     pos = pos - origin
 
+    if pos.ndim == 1:
+        return mass * cross(pos, vel)
     return mass[:, np.newaxis] * cross(pos, vel)
 
 
-def angular_velocity(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
+def angular_velocity(
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
+) -> Quantity:
     """Calculate the angular velocity.
 
     Parameters
     ----------
     snap
         The Snap object.
+    origin : optional
+        The origin around which to compute the angular velocity as a
+        Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -111,6 +114,10 @@ def angular_velocity(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
         pos = snap['position']
         vel = snap['velocity']
 
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
     x, y = pos[:, 0], pos[:, 1]
     vx, vy = vel[:, 0], vel[:, 1]
 
@@ -119,13 +126,18 @@ def angular_velocity(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     return vphi
 
 
-def azimuthal_angle(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
+def azimuthal_angle(
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
+) -> Quantity:
     """Calculate the azimuthal angle.
 
     Parameters
     ----------
     snap
         The Snap object.
+    origin : optional
+        The origin around which to compute the azimuthal angle as a
+        Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -140,6 +152,10 @@ def azimuthal_angle(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     else:
         pos = snap['position']
 
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
     x, y = pos[:, 0], pos[:, 1]
     return np.arctan2(y, x)
 
@@ -220,66 +236,6 @@ def dust_mass(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     return mass[:, np.newaxis] * _dust_fraction
 
 
-def eccentricity(
-    snap: SnapLike,
-    gravitational_parameter: Quantity = None,
-    origin: Quantity = None,
-    ignore_accreted: bool = False,
-) -> Quantity:
-    """Calculate the eccentricity.
-
-    The eccentricity of particles around a mass specified by
-    gravitational parameter with an optional to specify the position of
-    the mass.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    gravitational_parameter
-        The gravitational parameter (mu = G M) as a Pint quantity.
-    origin : optional
-        The origin around which to compute the eccentricity as a
-        Quantity like (x, y, z) * au. Default is (0, 0, 0).
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The eccentricity on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        pos: Quantity = snap['position'][h > 0]
-        vel: Quantity = snap['velocity'][h > 0]
-    else:
-        pos = snap['position']
-        vel = snap['velocity']
-
-    origin = snap.translation if snap.translation is not None else ORIGIN
-    pos = pos - origin
-
-    mu = snap.properties.get('gravitational_parameter')
-    if mu is None:
-        raise ValueError(
-            'must pass in gravitational_parameter or '
-            'set on Snap with set_gravitational_parameter'
-        )
-
-    radius = norm(pos, axis=1)
-
-    _specific_angular_momentum = cross(pos, vel)
-    specific_angular_momentum_magnitude = norm(_specific_angular_momentum, axis=1)
-
-    _specific_kinetic_energy = 1 / 2 * norm(vel, axis=1) ** 2
-    specific_potential_energy = -mu / radius
-    specific_energy = _specific_kinetic_energy + specific_potential_energy
-
-    term = specific_energy * (specific_angular_momentum_magnitude / mu) ** 2
-    return np.sqrt(1 + 2 * term)
-
-
 def gas_density(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     """Calculate the gas density.
 
@@ -386,95 +342,9 @@ def gas_mass(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     return mass * _gas_fraction
 
 
-def inclination(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
-    """Calculate the inclination.
-
-    The inclination is calculated by taking the angle between the
-    angular momentum vector and the z-axis, with the angular momentum
-    calculated with respect to the center of mass.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The inclination on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        mass: Quantity = snap['mass'][h > 0]
-        pos: Quantity = snap['position'][h > 0]
-        vel: Quantity = snap['velocity'][h > 0]
-    else:
-        mass = snap['mass']
-        pos = snap['position']
-        vel = snap['velocity']
-
-    origin = (mass[:, np.newaxis] * pos).sum(axis=0) / mass.sum()
-    pos = pos - origin
-
-    _specific_angular_momentum = cross(pos, vel)
-
-    return np.arccos(
-        _specific_angular_momentum[:, 2] / norm(_specific_angular_momentum, axis=1)
-    )
-
-
-def keplerian_frequency(
-    snap: SnapLike,
-    gravitational_parameter: Quantity = None,
-    origin: Quantity = None,
-    ignore_accreted: bool = False,
+def kinetic_energy(
+    snap: Union[SnapLike, Sinks], ignore_accreted: bool = False
 ) -> Quantity:
-    """Calculate the Keplerian orbital frequency.
-
-    The Keplerian orbital frequency of particles around a mass specified
-    by gravitational parameter with an optional to specify the position
-    of the mass.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    gravitational_parameter
-        The gravitational parameter (mu = G M) as a Pint quantity.
-    origin : optional
-        The origin around which to compute the Keplerian frequency as a
-        Quantity like (x, y, z) * au. Default is (0, 0, 0).
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The Keplerian frequency on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        pos: Quantity = snap['position'][h > 0]
-    else:
-        pos = snap['position']
-
-    origin = snap.translation if snap.translation is not None else ORIGIN
-    pos = pos - origin
-
-    mu = snap.properties.get('gravitational_parameter')
-    if mu is None:
-        raise ValueError(
-            'must pass in gravitational_parameter or '
-            'set on Snap with set_gravitational_parameter'
-        )
-
-    radius = norm(pos, axis=1)
-    return np.sqrt(mu / radius ** 3)
-
-
-def kinetic_energy(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     """Calculate the kinetic energy.
 
     Parameters
@@ -500,7 +370,7 @@ def kinetic_energy(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     return 1 / 2 * mass * norm(vel, axis=1) ** 2
 
 
-def momentum(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
+def momentum(snap: Union[SnapLike, Sinks], ignore_accreted: bool = False) -> Quantity:
     """Calculate the momentum.
 
     Parameters
@@ -523,16 +393,23 @@ def momentum(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
         mass = snap['mass']
         vel = snap['velocity']
 
+    if vel.ndim == 1:
+        return mass * vel
     return mass[:, np.newaxis] * vel
 
 
-def polar_angle(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
+def polar_angle(
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
+) -> Quantity:
     """Calculate the polar angle.
 
     Parameters
     ----------
     snap
         The Snap object.
+    origin : optional
+        The origin around which to compute the polar angle as a
+        Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -547,13 +424,19 @@ def polar_angle(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
     else:
         pos = snap['position']
 
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
     x, y, z = pos[:, 0], pos[:, 1], pos[:, 2]
     r = np.sqrt(x ** 2 + y ** 2 + z ** 2)
     return np.arccos(z / r)
 
 
 def radius_cylindrical(
-    snap: SnapLike, origin: Quantity = None, ignore_accreted: bool = False,
+    snap: Union[SnapLike, Sinks],
+    origin: Quantity = None,
+    ignore_accreted: bool = False,
 ) -> Quantity:
     """Calculate the cylindrical radial distance.
 
@@ -561,77 +444,8 @@ def radius_cylindrical(
     ----------
     snap
         The Snap object.
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The radial distance on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        pos: Quantity = snap['position'][h > 0]
-    else:
-        pos = snap['position']
-
-    origin = snap.translation if snap.translation is not None else ORIGIN
-    pos = pos - origin
-    x, y = pos[:, 0], pos[:, 1]
-
-    return np.sqrt(x ** 2 + y ** 2)
-
-
-def radius_spherical(
-    snap: SnapLike, origin: Quantity = None, ignore_accreted: bool = False,
-) -> Quantity:
-    """Calculate the spherical radial distance.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The radial distance on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        pos: Quantity = snap['position'][h > 0]
-    else:
-        pos = snap['position']
-
-    origin = snap.translation if snap.translation is not None else ORIGIN
-    pos = pos - origin
-    x, y, z = pos[:, 0], pos[:, 1], pos[:, 2]
-
-    return np.sqrt(x ** 2 + y ** 2 + z ** 2)
-
-
-def semi_major_axis(
-    snap: SnapLike,
-    gravitational_parameter: Quantity = None,
-    origin: Quantity = None,
-    ignore_accreted: bool = False,
-) -> Quantity:
-    """Calculate the semi-major axis.
-
-    The semi-major axis of particles around a mass specified by
-    gravitational parameter with an optional to specify the position of
-    the mass.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    gravitational_parameter
-        The gravitational parameter (mu = G M) as a Pint quantity.
     origin : optional
-        The origin around which to compute the semi-major axis as a
+        The origin around which to compute the cylindrical radius as a
         Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
@@ -639,44 +453,62 @@ def semi_major_axis(
     Returns
     -------
     Quantity
-        The semi-major axis on the particles.
+        The radial distance on the particles.
     """
     if ignore_accreted:
         h: Quantity = snap['smoothing_length']
         pos: Quantity = snap['position'][h > 0]
-        vel: Quantity = snap['velocity'][h > 0]
     else:
         pos = snap['position']
-        vel = snap['velocity']
 
-    origin = snap.translation if snap.translation is not None else ORIGIN
+    if origin is None:
+        origin = ORIGIN
     pos = pos - origin
 
-    mu = snap.properties.get('gravitational_parameter')
-    if mu is None:
-        raise ValueError(
-            'must pass in gravitational_parameter or '
-            'set on Snap with set_gravitational_parameter'
-        )
+    x, y = pos[:, 0], pos[:, 1]
 
-    radius = norm(pos, axis=1)
+    return np.sqrt(x ** 2 + y ** 2)
 
-    _specific_angular_momentum = cross(pos, vel)
-    specific_angular_momentum_magnitude = norm(_specific_angular_momentum, axis=1)
 
-    _specific_kinetic_energy = 1 / 2 * norm(vel, axis=1) ** 2
-    specific_potential_energy = -mu / radius
-    specific_energy = _specific_kinetic_energy + specific_potential_energy
+def radius_spherical(
+    snap: Union[SnapLike, Sinks],
+    origin: Quantity = None,
+    ignore_accreted: bool = False,
+) -> Quantity:
+    """Calculate the spherical radial distance.
 
-    term = specific_energy * (specific_angular_momentum_magnitude / mu) ** 2
+    Parameters
+    ----------
+    snap
+        The Snap object.
+    origin : optional
+        The origin around which to compute the spherical radius as a
+        Quantity like (x, y, z) * au. Default is (0, 0, 0).
+    ignore_accreted : optional
+        Ignore accreted particles. Default is False.
 
-    _eccentricity = np.sqrt(1 + 2 * term)
+    Returns
+    -------
+    Quantity
+        The radial distance on the particles.
+    """
+    if ignore_accreted:
+        h: Quantity = snap['smoothing_length']
+        pos: Quantity = snap['position'][h > 0]
+    else:
+        pos = snap['position']
 
-    return specific_angular_momentum_magnitude ** 2 / (mu * (1 - _eccentricity ** 2))
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
+    x, y, z = pos[:, 0], pos[:, 1], pos[:, 2]
+
+    return np.sqrt(x ** 2 + y ** 2 + z ** 2)
 
 
 def specific_angular_momentum(
-    snap: SnapLike, origin: Quantity = None, ignore_accreted: bool = False
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
 ) -> Quantity:
     """Calculate the specific angular momentum.
 
@@ -685,8 +517,8 @@ def specific_angular_momentum(
     snap
         The Snap object.
     origin : optional
-        The origin around which to compute the angular momentum as a
-        Quantity like (x, y, z) * au. Default is (0, 0, 0).
+        The origin around which to compute the specific angular momentum
+        as a Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -703,13 +535,16 @@ def specific_angular_momentum(
         pos = snap['position']
         vel = snap['velocity']
 
-    origin = snap.translation if snap.translation is not None else ORIGIN
+    if origin is None:
+        origin = ORIGIN
     pos = pos - origin
 
     return cross(pos, vel)
 
 
-def specific_kinetic_energy(snap: SnapLike, ignore_accreted: bool = False) -> Quantity:
+def specific_kinetic_energy(
+    snap: Union[SnapLike, Sinks], ignore_accreted: bool = False
+) -> Quantity:
     """Calculate the specific kinetic energy.
 
     Parameters
@@ -733,56 +568,6 @@ def specific_kinetic_energy(snap: SnapLike, ignore_accreted: bool = False) -> Qu
     return 1 / 2 * norm(vel, axis=1) ** 2
 
 
-def stokes_number(
-    snap: SnapLike,
-    gravitational_parameter: Quantity = None,
-    origin: Quantity = None,
-    ignore_accreted: bool = False,
-) -> Quantity:
-    """Calculate the Stokes number.
-
-    Parameters
-    ----------
-    snap
-        The Snap object.
-    gravitational_parameter
-        The gravitational parameter (mu = G M) as a Pint quantity.
-    origin : optional
-        The origin around which to compute the Stokes number as a
-        Quantity like (x, y, z) * au. Default is (0, 0, 0).
-    ignore_accreted : optional
-        Ignore accreted particles. Default is False.
-
-    Returns
-    -------
-    Quantity
-        The Stokes number on the particles.
-    """
-    if ignore_accreted:
-        h: Quantity = snap['smoothing_length']
-        pos: Quantity = snap['position'][h > 0]
-        t_s: Quantity = snap['stopping_time'][h > 0]
-    else:
-        pos = snap['position']
-        t_s = snap['stopping_time']
-
-    origin = snap.translation if snap.translation is not None else ORIGIN
-    pos = pos - origin
-
-    mu = snap.properties.get('gravitational_parameter')
-    if mu is None:
-        raise ValueError(
-            'must pass in gravitational_parameter or '
-            'set on Snap with set_gravitational_parameter'
-        )
-
-    radius = norm(pos, axis=1)
-    Omega_k = np.sqrt(mu / radius ** 3)
-
-    Stokes = t_s * Omega_k[:, np.newaxis]
-    return Stokes
-
-
 def temperature(
     snap: SnapLike, molecular_weight: float = None, ignore_accreted: bool = False
 ) -> Quantity:
@@ -826,7 +611,7 @@ def temperature(
 
 
 def velocity_radial_cylindrical(
-    snap: SnapLike, ignore_accreted: bool = False
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
 ) -> Quantity:
     """Calculate the cylindrical radial velocity.
 
@@ -834,6 +619,10 @@ def velocity_radial_cylindrical(
     ----------
     snap
         The Snap object.
+    origin : optional
+        The origin around which to compute the cylindrical radial
+        velocity as a Quantity like (x, y, z) * au. Default is
+        (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -850,6 +639,10 @@ def velocity_radial_cylindrical(
         pos = snap['position']
         vel = snap['velocity']
 
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
     x, y = pos[:, 0], pos[:, 1]
     vx, vy = vel[:, 0], vel[:, 1]
 
@@ -857,7 +650,7 @@ def velocity_radial_cylindrical(
 
 
 def velocity_radial_spherical(
-    snap: SnapLike, ignore_accreted: bool = False
+    snap: Union[SnapLike, Sinks], origin: Quantity = None, ignore_accreted: bool = False
 ) -> Quantity:
     """Calculate the spherical radial velocity.
 
@@ -865,6 +658,9 @@ def velocity_radial_spherical(
     ----------
     snap
         The Snap object.
+    origin : optional
+        The origin around which to compute the spherical radial velocity
+        as a Quantity like (x, y, z) * au. Default is (0, 0, 0).
     ignore_accreted : optional
         Ignore accreted particles. Default is False.
 
@@ -881,6 +677,10 @@ def velocity_radial_spherical(
         pos = snap['position']
         vel = snap['velocity']
 
+    if origin is None:
+        origin = ORIGIN
+    pos = pos - origin
+
     x, y, z = pos[:, 0], pos[:, 1], pos[:, 2]
     vx, vy, vz = vel[:, 0], vel[:, 1], vel[:, 2]
 
