@@ -3,21 +3,65 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Callable, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Tuple, Union
 
 import h5py
 import numpy as np
 
-from ..._config import load_config
 from ..._logging import logger
-from ..._units import Quantity, array_units, generate_array_code_units
+from ..._units import Quantity
 from ..._units import units as plonk_units
-from ...utils.snap import add_aliases
-from ..extra import extra_quantities
-from ..snap import Snap
+
+if TYPE_CHECKING:
+    from ..snap import Snap
 
 igas, iboundary, istar, idarkmatter, ibulge = 1, 3, 4, 5, 6
 bignumber = 1e29
+missing_infile_parameters = ['alpha', 'alphaB', 'alphau', 'C_cour', 'C_force', 'tolh']
+
+
+def add_to_header_from_infile(
+    snapfile: Union[str, Path], infile: Union[str, Path], parameters: List[str] = None,
+):
+    """Add missing values to Phantom snapshot header.
+
+    Some values can be missing from the Phantom snapshot header after
+    conversion from the non-HDF5 file format. These values are
+    available in the in-file. This function reads the infile and sets
+    the values in the Phantom-HDF5 snapshot file header.
+
+    Parameters
+    ----------
+    snapfile
+        The path to the snapshot file.
+    infile
+        The path to the in-file.
+    parameters : optional
+        A list of strings of parameters to set in the snap header from
+        the in-file.
+    """
+    try:
+        import phantomconfig as pc
+    except ModuleNotFoundError as e:
+        print(
+            'phantom-config unavailable, '
+            'install with python -m pip install phantomconfig'
+        )
+        raise e
+    if parameters is None:
+        parameters = missing_infile_parameters
+    config = pc.read_config(infile)
+    logger.info(f'Reading parameters in {infile}')
+    filename = Path(snapfile).expanduser()
+    if not filename.is_file():
+        raise FileNotFoundError('Cannot find snapshot file')
+    file = h5py.File(filename, mode='r+')
+    logger.info(f'Opening snapshot file {snapfile}')
+    for param in parameters:
+        if param in config.config:
+            logger.info(f'Updating {param} from in-file')
+            file[f'header/{param}'][()] = config.config[param].value
+    file.close()
 
 
 def fileid(snap: Snap) -> str:
@@ -39,107 +83,24 @@ def fileid(snap: Snap) -> str:
     return snap._file_pointer['header/fileident'][()].decode()
 
 
-def generate_snap_from_file(
-    filename: Union[str, Path], config: Union[str, Path] = None
-) -> Snap:
-    """Generate a Snap object from a Phantom HDF5 file.
+def snap_properties_and_units(
+    file_pointer: h5py.File,
+) -> Tuple[Dict[str, Any], Dict[str, Quantity]]:
+    """Generate snap properties and units.
 
     Parameters
     ----------
-    filename
-        The path to the file.
-    config : optional
-        The path to a Plonk config.toml file.
+    file_pointer
+        The h5py file pointer to the snap file.
 
     Returns
     -------
-    Snap
-        A Snap object.
-    """
-    logger.debug(f'Loading Phantom snapshot: {filename}')
-
-    # REQUIRED: Instantiate Snap.
-    snap = Snap()
-
-    # REQUIRED: Set snap.data_source.
-    snap.data_source = 'Phantom'
-
-    # REQUIRED: Set snap.file_path.
-    file_path = Path(filename).expanduser()
-    if not file_path.is_file():
-        raise FileNotFoundError('Cannot find snapshot file')
-    snap.file_path = file_path
-
-    # REQUIRED: Set snap._file_pointer.
-    file_handle = h5py.File(file_path, mode='r')
-    snap._file_pointer = file_handle
-
-    # REQUIRED: Set snap._properties, snap._code_units, and snap._array_code_units.
-    header = {key: val[()] for key, val in file_handle['header'].items()}
-    snap._properties, snap._code_units = header_to_properties(header)
-    snap._array_code_units = generate_array_code_units(snap._code_units)
-
-    # OPTIONAL: Set snap._units.
-    snap._default_units = array_units(config=config)
-
-    # OPTIONAL: Set snap._name_map.
-    conf = load_config(filename=config)
-    snap._name_map = {
-        'particles': conf['phantom']['particles']['namemap'],
-        'sinks': conf['phantom']['sinks']['namemap'],
-    }
-
-    # REQUIRED: Set snap._array_registry dictionary.
-    #
-    # The keys are the names of the arrays and the values are functions that return the
-    # array when called with snap as the argument.
-    arrays = list(file_handle['particles'])
-    ndustsmall = header['ndustsmall']
-    ndustlarge = header['ndustlarge']
-    array_registry = populate_particle_array_registry(
-        arrays=arrays,
-        name_map=snap._name_map['particles'],
-        ndustsmall=ndustsmall,
-        ndustlarge=ndustlarge,
-    )
-    snap._array_registry.update(array_registry)
-
-    # REQUIRED (if there are sink particles): Set _sink_registry.
-    #
-    # The keys are the names of the arrays and the values are functions that return the
-    # array when called with snap as the argument.
-    if header['nptmass'] > 0:
-        sinks = list(file_handle['sinks'])
-        sink_registry = populate_sink_array_registry(
-            sinks=sinks, name_map=snap._name_map['sinks']
-        )
-        snap._sink_registry.update(sink_registry)
-
-    # OPTIONAL: Add aliases
-    add_aliases(snap)
-
-    # OPTIONAL: Make extra derived quantities available.
-    extra_quantities(snap)
-
-    # REQUIRED: Return Snap object.
-    return snap
-
-
-def header_to_properties(header: dict):
-    """Convert Phantom header to properties and units.
-
-    Parameters
-    ----------
-    header
-        The Phantom header as a dict.
-
-    Returns
-    -------
-    prop
+    properties
         The properties as a dict.
-    units
-        The units as a dict.
+    code_units
+        The code units as a dict.
     """
+    header = {key: val[()] for key, val in file_pointer['header'].items()}
     length = (header['udist'] * plonk_units('cm')).to_base_units()
     time = (header['utime'] * plonk_units('s')).to_base_units()
     mass = (header['umass'] * plonk_units('g')).to_base_units()
@@ -151,7 +112,7 @@ def header_to_properties(header: dict):
     ).to_base_units()
     current = (mass / time ** 2 / magnetic_field).to_base_units()
 
-    units = {
+    code_units = {
         'length': length,
         'time': time,
         'mass': mass,
@@ -159,22 +120,22 @@ def header_to_properties(header: dict):
         'current': current,
     }
 
-    prop = dict()
+    properties = dict()
 
-    prop['time'] = header['time'] * units['time']
-    prop['smoothing_length_factor'] = header['hfact']
+    properties['time'] = header['time'] * code_units['time']
+    properties['smoothing_length_factor'] = header['hfact']
 
     gamma = header['gamma']
     ieos = header['ieos']
     if ieos == 1:
-        prop['equation_of_state'] = 'isothermal'
-        prop['adiabatic_index'] = gamma
+        properties['equation_of_state'] = 'isothermal'
+        properties['adiabatic_index'] = gamma
     elif ieos == 2:
-        prop['equation_of_state'] = 'adiabatic'
-        prop['adiabatic_index'] = gamma
+        properties['equation_of_state'] = 'adiabatic'
+        properties['adiabatic_index'] = gamma
     elif ieos == 3:
-        prop['equation_of_state'] = 'locally isothermal disc'
-        prop['adiabatic_index'] = gamma
+        properties['equation_of_state'] = 'locally isothermal disc'
+        properties['adiabatic_index'] = gamma
 
     ndustsmall = header['ndustsmall']
     ndustlarge = header['ndustlarge']
@@ -184,46 +145,50 @@ def header_to_properties(header: dict):
             'or dust as separate sets of particles (aka multi-fluid dust).'
         )
     if ndustsmall > 0:
-        prop['dust_method'] = 'dust/gas mixture'
+        properties['dust_method'] = 'dust/gas mixture'
     elif ndustlarge > 0:
-        prop['dust_method'] = 'dust as separate sets of particles'
+        properties['dust_method'] = 'dust as separate sets of particles'
 
     n_dust = ndustsmall + ndustlarge
     if n_dust > 0:
-        prop['grain_size'] = header['grainsize'][:n_dust] * units['length']
-        prop['grain_density'] = (
-            header['graindens'][:n_dust] * units['mass'] / units['length'] ** 3
+        properties['grain_size'] = header['grainsize'][:n_dust] * code_units['length']
+        properties['grain_density'] = (
+            header['graindens'][:n_dust]
+            * code_units['mass']
+            / code_units['length'] ** 3
         )
 
-    return prop, units
+    return properties, code_units
 
 
-def populate_particle_array_registry(
-    arrays: List[str],
-    name_map: Dict[str, str],
-    ndustsmall: int = 0,
-    ndustlarge: int = 0,
-):
-    """Populate particle arrays registry.
+def snap_array_registry(
+    file_pointer: h5py.File, name_map: Dict[str, str] = None
+) -> Dict[str, Callable]:
+    """Generate snap array registry.
 
     Parameters
     ----------
-    arrays
-        A list of particle array names as they are on file.
-    name_map
+    file_pointer
+        The h5py file pointer to the snap file.
+    name_map : optional
         A dict to convert from Phantom array names to Plonk names.
-    ndustsmall
-        The number of "small" dust species. I.e. the number of mixture
-        method (1-fluid) dust species.
-    ndustlarge
-        The number of "large" dust species. I.e. the number of separate
-        sets of particles (2-fluid) dust species.
 
     Returns
     -------
     Dict
         The particle array registry.
     """
+    # The keys are the names of the arrays and the values are functions that return the
+    # array when called with snap as the argument.
+
+    if name_map is None:
+        name_map = {}
+
+    header = {key: val[()] for key, val in file_pointer['header'].items()}
+    arrays = list(file_pointer['particles'])
+    ndustsmall = header['ndustsmall']
+    ndustlarge = header['ndustlarge']
+
     array_registry = dict()
 
     # Each particle gets an id
@@ -268,14 +233,16 @@ def populate_particle_array_registry(
     return array_registry
 
 
-def populate_sink_array_registry(sinks: List[str], name_map: Dict[str, str]):
-    """Populate particle arrays registry.
+def snap_sink_registry(
+    file_pointer: h5py.File, name_map: Dict[str, str] = None
+) -> Dict[str, Callable]:
+    """Generate snap sink registry.
 
     Parameters
     ----------
-    sinks
-        A list of sink array names as they are on file.
-    name_map
+    file_pointer
+        The h5py file pointer to the snap file.
+    name_map : optional
         A dict to convert from Phantom array names to Plonk names.
 
     Returns
@@ -283,19 +250,30 @@ def populate_sink_array_registry(sinks: List[str], name_map: Dict[str, str]):
     Dict
         The sink array registry.
     """
-    sink_registry = dict()
+    # The keys are the names of the arrays and the values are functions that return the
+    # array when called with snap as the argument.
 
-    # Read arrays if available
-    for name_on_file, name in name_map.items():
-        if name_on_file in sinks:
-            sink_registry[name] = get_dataset(name_on_file, 'sinks')
-            sinks.remove(name_on_file)
+    if name_map is None:
+        name_map = {}
+    header = {key: val[()] for key, val in file_pointer['header'].items()}
 
-    # Read *any* extra arrays
-    for sink in sinks:
-        sink_registry[sink] = get_dataset(sink, 'sinks')
+    if header['nptmass'] > 0:
+        sinks = list(file_pointer['sinks'])
+        sink_registry = dict()
 
-    return sink_registry
+        # Read arrays if available
+        for name_on_file, name in name_map.items():
+            if name_on_file in sinks:
+                sink_registry[name] = get_dataset(name_on_file, 'sinks')
+                sinks.remove(name_on_file)
+
+        # Read *any* extra arrays
+        for sink in sinks:
+            sink_registry[sink] = get_dataset(sink, 'sinks')
+
+        return sink_registry
+
+    return {}
 
 
 def get_dataset(dataset: str, group: str) -> Callable:
