@@ -19,12 +19,21 @@ from scipy.spatial import cKDTree
 from scipy.spatial.transform import Rotation
 
 from .. import visualize
+from .._config import read_config
 from .._logging import logger
-from .._units import Quantity
+from .._units import Quantity, array_units, generate_array_code_units
 from .._units import units as plonk_units
 from ..utils.kernels import kernel_names, kernel_radius
 from ..utils.math import norm
+from ..utils.snap import add_aliases
 from . import context
+from .extra import add_quantities as _add_quantities
+from .readers import (
+    DATA_SOURCES,
+    snap_array_registry,
+    snap_properties_and_units,
+    snap_sink_registry,
+)
 
 
 class Snap:
@@ -129,6 +138,81 @@ class Snap:
         self.translation = None
         self._tree = None
 
+    def load_snap(
+        self,
+        filename: Union[str, Path],
+        data_source: str,
+        config: Union[str, Path] = None,
+    ):
+        """Load snapshot from file.
+
+        Parameters
+        ----------
+        filename
+            The path to the file.
+        data_source : optional
+            The SPH software that produced the data. Default is 'phantom'.
+        config : optional
+            The path to a Plonk config.toml file.
+        """
+        logger.debug(f'Loading Phantom snapshot: {filename}')
+
+        # Set file_path
+        file_path = Path(filename).expanduser()
+        if not file_path.is_file():
+            raise FileNotFoundError('Cannot find snapshot file')
+        self.file_path = file_path
+
+        # Set file_pointer
+        self._file_pointer = h5py.File(file_path, mode='r')
+
+        # Set data_source
+        if data_source.lower() not in DATA_SOURCES:
+            raise ValueError(
+                f'Unknown data source. Available data sources:\n{DATA_SOURCES}'
+            )
+        self.data_source = data_source
+
+        # Set properties and units
+        self._properties, self._code_units = snap_properties_and_units(
+            file_pointer=self._file_pointer, data_source=self.data_source
+        )
+        self._array_code_units = generate_array_code_units(self._code_units)
+        self._default_units = array_units(config=config)
+
+        # Set name_map
+        conf = read_config(filename=config)
+        self._name_map = {
+            'particles': conf[self.data_source]['particles']['namemap'],
+            'sinks': conf[self.data_source]['sinks']['namemap'],
+        }
+
+        # Set array_registry
+        self._array_registry.update(
+            snap_array_registry(
+                file_pointer=self._file_pointer,
+                data_source=self.data_source,
+                name_map=self._name_map['particles'],
+            )
+        )
+
+        # Set sink_registry
+        self._sink_registry.update(
+            snap_sink_registry(
+                file_pointer=self._file_pointer,
+                data_source=self.data_source,
+                name_map=self._name_map['sinks'],
+            )
+        )
+
+        # Add aliases
+        add_aliases(self, filename=config)
+
+        # Make extra derived quantities available
+        self.add_quantities()
+
+        return self
+
     def close_file(self):
         """Close access to underlying file."""
         self._file_pointer.close()
@@ -388,30 +472,34 @@ class Snap:
     def num_particles(self) -> int:
         """Return number of particles."""
         if self._num_particles == -1:
-            self._num_particles = len(self['type'])
+            with self.context(cache=False):
+                self._num_particles = len(self['type'])
         return self._num_particles
 
     @property
     def num_particles_of_type(self) -> Dict[str, Any]:
         """Return number of particles per type."""
         if self._num_particles_of_type == -1:
-            int_to_name = {idx: name for name, idx in self.particle_type.items()}
-            d = {}
-            ptype: Quantity = self['type']
-            stype: Quantity = self['sub_type']
-            for idx, num in enumerate(np.bincount(ptype.magnitude)):
-                if num > 0:
-                    if idx == self.particle_type['dust']:
-                        # Dust particle sub-type skips zero: 1, 2, 3 ...
-                        d['dust'] = list(
-                            np.bincount(stype[ptype.magnitude == idx].magnitude)[1:]
-                        )
-                    elif idx == self.particle_type['boundary']:
-                        # Boundary particle sub-type: 0 (gas), 1, 2, 3... (dust)
-                        d['boundary'] = list(np.bincount(stype[ptype == idx].magnitude))
-                    else:
-                        d[int_to_name[idx]] = num
-            self._num_particles_of_type = d
+            with self.context(cache=False):
+                int_to_name = {idx: name for name, idx in self.particle_type.items()}
+                d = {}
+                ptype: Quantity = self['type']
+                stype: Quantity = self['sub_type']
+                for idx, num in enumerate(np.bincount(ptype.magnitude)):
+                    if num > 0:
+                        if idx == self.particle_type['dust']:
+                            # Dust particle sub-type skips zero: 1, 2, 3 ...
+                            d['dust'] = list(
+                                np.bincount(stype[ptype.magnitude == idx].magnitude)[1:]
+                            )
+                        elif idx == self.particle_type['boundary']:
+                            # Boundary particle sub-type: 0 (gas), 1, 2, 3... (dust)
+                            d['boundary'] = list(
+                                np.bincount(stype[ptype == idx].magnitude)
+                            )
+                        else:
+                            d[int_to_name[idx]] = num
+                self._num_particles_of_type = d
         return self._num_particles_of_type
 
     @property
@@ -428,7 +516,7 @@ class Snap:
     def num_dust_species(self) -> int:
         """Return number of dust species."""
         if self._num_dust_species == -1:
-            self._num_dust_species = len(self._properties.get('grain_size', []))
+            self._num_dust_species = len(self.properties.get('grain_size', []))
         return self._num_dust_species
 
     @property
@@ -522,18 +610,11 @@ class Snap:
             _rotation = axis / norm(axis) * angle
         if isinstance(_rotation, (list, tuple, ndarray)):
             _rotation = Rotation.from_rotvec(_rotation)
-        for arr in self._vector_arrays:
-            if arr in self.loaded_arrays():
-                array_m, array_u = self._arrays[arr].magnitude, self._arrays[arr].units
-                self._arrays[arr] = _rotation.apply(array_m) * array_u
-            if self.num_sinks > 0 and arr in self.sinks.loaded_arrays():
-                array_m = self._sink_arrays[arr].magnitude
-                array_u = self._sink_arrays[arr].units
-                self._sink_arrays[arr] = _rotation.apply(array_m) * array_u
-        for arr in self._vector_arrays:
-            if arr in self.loaded_arrays():
-                del self._arrays[arr]
-            if self.num_sinks > 0 and arr in self.sinks.loaded_arrays():
+
+        for arr in self.loaded_arrays():
+            del self[arr]
+        if self.num_sinks > 0:
+            for arr in self.sinks.loaded_arrays():
                 del self._sink_arrays[arr]
 
         if self.rotation is None:
@@ -568,7 +649,7 @@ class Snap:
         """
         logger.debug(f'Translating snapshot: {self.file_path.name}')
         if isinstance(translation, (list, tuple)):
-            translation = np.array(translation)
+            translation = np.array(translation, dtype=np.float)
         if translation.shape != (3,):
             raise ValueError('translation must be like (x, y, z)')
         if isinstance(translation, Quantity):
@@ -580,10 +661,12 @@ class Snap:
                     'translation must have units, or you must specify units argument'
                 )
             translation *= plonk_units(unit)
-        if 'position' in self.loaded_arrays():
-            self._arrays['position'] += translation
-        if self.num_sinks > 0 and 'position' in self.sinks.loaded_arrays():
-            self._sink_arrays['position'] += translation
+
+        for arr in self.loaded_arrays():
+            del self[arr]
+        if self.num_sinks > 0:
+            for arr in self.sinks.loaded_arrays():
+                del self._sink_arrays[arr]
 
         if self.translation is None:
             self.translation = translation
@@ -593,7 +676,7 @@ class Snap:
         return self
 
     def particle_indices(
-        self, particle_type: str, squeeze: bool = False,
+        self, particle_type: str, squeeze: bool = False
     ) -> Union[ndarray, List[ndarray]]:
         """Particle indices of a particular type.
 
@@ -613,12 +696,15 @@ class Snap:
             indices, one for each subtype. However, if squeeze
             is True, return a single array.
         """
+        with self.context(cache=False):
+            ptype = self['type']
+            stype = self['sub_type']
+
         if particle_type == 'dust' and not squeeze:
             # Dust particle sub-type skips zero: 1, 2, 3 ...
             return [
                 np.flatnonzero(
-                    (self['type'] == self.particle_type['dust'])
-                    & (self['sub_type'] == idx + 1)
+                    (ptype == self.particle_type['dust']) & (stype == idx + 1)
                 )
                 for idx in range(self.num_dust_species)
             ]
@@ -626,12 +712,11 @@ class Snap:
             # Boundary particle sub-type: 0 (gas), 1, 2, 3... (dust)
             return [
                 np.flatnonzero(
-                    (self['type'] == self.particle_type['boundary'])
-                    & (self['sub_type'] == idx)
+                    (ptype == self.particle_type['boundary']) & (stype == idx)
                 )
                 for idx in range(self.num_dust_species + 1)
             ]
-        return np.flatnonzero(self['type'] == self.particle_type[particle_type])
+        return np.flatnonzero(ptype == self.particle_type[particle_type])
 
     def subsnaps_as_dict(
         self, squeeze: bool = False
@@ -701,14 +786,15 @@ class Snap:
 
         return self
 
-    def set_gravitational_parameter(self, sink_idx: Union[int, List[int]]) -> Snap:
-        """Set standard gravitational parameter.
+    def set_central_body(self, sink_idx: Union[int, List[int]]) -> Snap:
+        """Set the central body for orbital dynamics.
 
-        Calculate the standard gravitational parameter (G M) given a
-        sink index, or list of sink indices for multiple systems, etc,
-        and set snap.properties['gravitational_parameter']. This is
-        required to calculate orbital quantities such as eccentricity
-        or Stokes number.
+        The central body can be a sink particle or multiple sink
+        particles given by a sink index, or list of sink indices. This
+        method sets snap.properties['central_body'] with the central
+        body mass, barycenter position and velocity. This is required to
+        calculate orbital quantities on the particles such as
+        eccentricity.
 
         Parameters
         ----------
@@ -720,13 +806,23 @@ class Snap:
         Snap
             The Snap.
         """
-        G = plonk_units.newtonian_constant_of_gravitation
         if isinstance(sink_idx, (int, list)):
-            M = self.sinks[sink_idx]['mass']
+            mass = self.sinks[sink_idx]['mass']
+            position = self.sinks[sink_idx]['position']
+            velocity = self.sinks[sink_idx]['velocity']
         else:
-            raise ValueError('Cannot determine gravitational parameter')
-        G = (G * M).to_base_units()
-        self._properties['gravitational_parameter'] = G
+            raise ValueError('Cannot determine the central body')
+        if position.ndim == 1:
+            barycenter = position
+            velocity = velocity
+        elif position.ndim == 2:
+            barycenter = (mass[:, np.newaxis] * position).sum(axis=0) / np.sum(mass)
+            velocity = (mass[:, np.newaxis] * velocity).sum(axis=0) / np.sum(mass)
+        self._properties['central_body'] = {
+            'mass': np.sum(mass),
+            'position': barycenter,
+            'velocity': velocity,
+        }
 
         return self
 
@@ -923,13 +1019,12 @@ class Snap:
         Returns
         -------
         SubSnap or List[SubSnap]
-            If the particle family has no sub-types then return a
-            SubSnap. Otherwise, if split_subtype is True, return a list
-            of SubSnaps.
         """
         if name in self.particle_type:
             ind = self.particle_indices(particle_type=name, squeeze=squeeze)
             if isinstance(ind, list):
+                if len(ind) == 0:
+                    raise ValueError('Family has no particles')
                 if len(ind[0]) == 0:
                     raise ValueError('Family has no particles')
                 return [SubSnap(self, _ind) for _ind in ind]
@@ -1184,10 +1279,12 @@ class Snap:
         """Dunder str method."""
         return f'<plonk.Snap "{self.file_path.name}">'
 
+    # Add methods defined in other modules
     image = visualize.image
     plot = visualize.plot
     vector = visualize.vector
     context = context.context
+    add_quantities = _add_quantities
 
 
 class SubSnap(Snap):
@@ -1328,6 +1425,8 @@ class Sinks:
         self.file_path = self.base.file_path
         self.base_array_name = self.base.base_array_name
         self.default_units = self.base.default_units
+        self.rotation = self.base.rotation
+        self.translation = self.base.translation
 
     @property
     def indices(self) -> ndarray:
