@@ -4,19 +4,22 @@ The Plonk implementation for visualizing smoothed particle hydrodynamics
 simulations using kernel density estimation based interpolation.
 """
 
-from .animation import animation, animation_particles, animation_profiles
-from .functions import get_extent_from_percentile, plot_smoothing_length
+from .animation import (
+    animate,
+    animation_images,
+    animation_particles,
+    animation_profiles,
+)
 from .interpolation import interpolate
 from .simulation import visualize_sim
 from .visualization import image, plot, vector
 
 __all__ = [
-    'animation',
+    'animate',
+    'animation_images',
     'animation_particles',
     'animation_profiles',
-    'get_extent_from_percentile',
     'image',
-    'plot_smoothing_length',
     'interpolate',
     'plot',
     'vector',
