@@ -5,11 +5,13 @@ from pathlib import Path
 import plonk
 from plonk import visualize
 
+DIR_PATH = Path(__file__).parent / 'data/phantom'
+PREFIX = 'dustseparate'
+
 
 def test_animate():
     """Test animate."""
-    dir_path = Path(__file__).parent / 'stubdata'
-    sim = plonk.load_sim(prefix='phantom', directory=dir_path)
+    sim = plonk.load_simulation(prefix=PREFIX, directory=DIR_PATH)
 
     snaps = [sim.snaps[0], sim.snaps[0], sim.snaps[0]]
     filename = Path('animation.mp4')
@@ -19,15 +21,14 @@ def test_animate():
         quantity='density',
         units={'position': 'au', 'density': 'g/cm^3'},
         adaptive_colorbar=False,
-        number_of_pixels=(32, 32),
+        num_pixels=(32, 32),
     )
     filename.unlink()
 
 
 def test_animation_images():
     """Test animation of images."""
-    dir_path = Path(__file__).parent / 'stubdata'
-    sim = plonk.load_sim(prefix='phantom', directory=dir_path)
+    sim = plonk.load_simulation(prefix=PREFIX, directory=DIR_PATH)
 
     snaps = [sim.snaps[0], sim.snaps[0], sim.snaps[0]]
     filename = Path('animation.mp4')
@@ -37,15 +38,14 @@ def test_animation_images():
         quantity='density',
         units={'position': 'au', 'density': 'g/cm^3'},
         adaptive_colorbar=False,
-        number_of_pixels=(32, 32),
+        num_pixels=(32, 32),
     )
     filename.unlink()
 
 
 def test_animation_profiles():
     """Test animation of profiles."""
-    dir_path = Path(__file__).parent / 'stubdata'
-    sim = plonk.load_sim(prefix='phantom', directory=dir_path)
+    sim = plonk.load_simulation(prefix=PREFIX, directory=DIR_PATH)
 
     snaps = [sim.snaps[0], sim.snaps[0], sim.snaps[0]]
     profiles = [plonk.load_profile(snap) for snap in snaps]
@@ -63,8 +63,7 @@ def test_animation_profiles():
 
 def test_animation_particles():
     """Test animation of particle plots."""
-    dir_path = Path(__file__).parent / 'stubdata'
-    sim = plonk.load_sim(prefix='phantom', directory=dir_path)
+    sim = plonk.load_simulation(prefix=PREFIX, directory=DIR_PATH)
 
     snaps = [sim.snaps[0], sim.snaps[0], sim.snaps[0]]
     filename = Path('animation.mp4')
