@@ -8,21 +8,18 @@ import pytest
 import plonk
 from plonk import analysis
 
-TEST_FILE = Path(__file__).parent / 'stubdata/phantom_00000.h5'
-NEIGHBOURS_FILE = Path(__file__).parent / 'stubdata/neighbours.csv'
+from .data.phantom import dustseparate
 
-with open(NEIGHBOURS_FILE) as fp:
-    NEIGHBOURS = list()
-    lines = fp.readlines()
-    for line in lines:
-        if line[0] == '#':
-            continue
-        NEIGHBOURS.append([int(item) for item in line.strip().split(',')])
+DIR = Path(__file__).parent / 'data/phantom'
 
 
 def test_get_neighbours():
     """Testing getting particle neighbours."""
-    snap = plonk.load_snap(TEST_FILE)
+    filename = DIR / dustseparate.filename
+    snap = plonk.load_snap(filename)
+
+    filename = DIR / dustseparate.neighbours_file
+    neighbours = _neighbours(filename)
 
     with pytest.raises(ValueError):
         snap.set_kernel('kernel_does_not_exist')
@@ -33,17 +30,29 @@ def test_get_neighbours():
     indices = np.arange(len(subsnap))
     neigh = subsnap.neighbours(indices)
     for idxi, idxj in enumerate(indices):
-        assert set(neigh[idxi]) == set(NEIGHBOURS[idxj])
+        assert set(neigh[idxi]) == set(neighbours[idxj])
 
     snap.close_file()
 
 
 def test_sph_derivative():
     """Test SPH derivative."""
-    snap = plonk.load_snap(TEST_FILE)
+    filename = DIR / dustseparate.filename
+    snap = plonk.load_snap(filename)
 
     analysis.sph.derivative(
         snap=snap, derivative='div', quantity='velocity', kernel='cubic',
     )
 
     snap.close_file()
+
+
+def _neighbours(neighbours_file):
+    with open(neighbours_file) as fp:
+        neighbours = list()
+        lines = fp.readlines()
+        for line in lines:
+            if line[0] == '#':
+                continue
+            neighbours.append([int(item) for item in line.strip().split(',')])
+    return neighbours
